% INIT.m Inizializza parametri problema di regolazione della potenza
%        idraulica in una condotta forzata
%
% Tutte i parametri sono in unita' SI

% Queste variabili sono globali perche' vengono utilizzate all'interno delle 
% funzioni G(s), Gid(s), Gidfm(s) e Gidfnm(s)

global tau beta Ta Tatt

% Parametri impianto e punto di lavoro (indipendenti)
h = 1000    % Altezza del pelo libero del bacino sulla turbina, [m]
Cf = 0.005  % Coefficiente di attrito di Fanning
Lg = 5000   % Lunghezza galleria, [m]
Lc = 1200   % Lunghezza condotta, [m]
Dg = 5      % Diametro galleria, [m]
Dc = 3      % Diametro condotta, [m]
ro = 1000   % Densita' acqua, [kg/m3]
Ap = 40     % Sezione pozzo, [m2]
g = 9.81    % Accelerazione di gravita', [m/s2]
eta = 0.88  % Rendimento idraulico turbina Pelton, [pu]
w_ = 40000   % Portata nominale, [kg/s]
c = 1000    % Velocita' del suono, [m/s]
Ta = 10     % Tempo di avviamento turbina [s]
Tatt = 0.3  % Costante di tempo attuatore idraulico ugello

% Altri parameteri (dipendenti)
Ag = pi*(Dg/2)^2  % Sezione galleria, [m2]
Ac = pi*(Dc/2)^2  % Sezione condotta, [m2]

DPideale = ro*g*h     % Salto di pressione teorico in assenza di attrito

DPg = Cf*(2*pi*Dg)*Lg/(2*ro * Ag^3)*w_^2  % Caduta di pressione galleria, [Pa]
DPc = Cf*(2*pi*Dc)*Lg/(2*ro * Ac^3)*w_^2  % Caduta di pressione condotta, [Pa]
DPreale = DPideale - DPg - DPc           % Salto di pressione reale all'ugello [Pa]

Pid_ideale = w_/ro*DPideale  % Potenza idraulica ideale
Pid = w_/ro*DPreale          % Potenza idraulica reale

Ig = Lg/Ag        % Inertanza galleria
Rg = 2*DPg/w_     % Resistenza galleria
Ic = Lc/Ac        % Inertanza condotta
Rc = 2*DPc/w_     % Resistenza galleria
Ru = 2*DPreale/w_ % Resistenza ugello
Rt = Ru+Rc+Rg     % Resistenza totale
Z = c/Ac          % Impedenza caratteristica condotta
C = Ap/g          % Capacita' pozzo piezometrico
Au = w_/sqrt(2*ro*DPreale); % Area di efflusso ugello
mu = w_/Au;       % Guadagno generatore di portata ugello

tau = Lc / c     % Tempo di propagazione onde in condotta
beta = Z / Ru    % Parametero dell'Allievi

Tc = Ic / Ru           % Costante di tempo RL della condotta
omegan = 1/sqrt(Ig*C)  % Pulsazione naturale pozzo-galleria
Tg = 2*pi/omegan       % Pseudo-periodo pozzo-galleria

Kc = 1 % fattore correttivo guadagno regolatore


